@@ -327,6 +327,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 	// package_nameにParam.PACKAGE + view|logic を付加する。
 	private String package_name;
 	private String java_path;
+	private String org_file_name;
 	private String class_name;
 	private String enum_name;
 	private long	html_last_time = 0;
@@ -422,10 +423,11 @@ public class PrePage extends DynamicPage implements OutputNo {
 			enum_name = "";
 		}
 
-		class_name = name2CamelCase( tmp.getName() );
+		org_file_name = tmp.getName();
+		class_name = name2CamelCase( org_file_name );
 
 		StringBuilder	buf = new StringBuilder( enum_name );
-		enum_name = tmp.getName().toUpperCase();
+		enum_name = org_file_name.toUpperCase();
 		String[]	part = enum_name.split( "[\\p{Punct}\\p{Space}]+" );
 		for ( int i = 0; i < part.length; i++ ) {
 			if ( i > 0 )	buf = buf.append( "_" );
@@ -537,11 +539,11 @@ public class PrePage extends DynamicPage implements OutputNo {
 	protected Tag makeTag( String name, ArrayList<Attribute> attr ) throws Exception {
 		TagSource	nt = null;
 		if ( name.equalsIgnoreCase( "table" ) ) {
-			nt = new TableSource();
+			nt = new TableSource( org_file_name );
 			table.add( (TableSource)nt );
 		}
 		else {
-			nt = new TagSource( name, isSimpleTag( name ) );
+			nt = new TagSource( org_file_name, name, isSimpleTag( name ) );
 		}
 		int	cnt = attr.size();
 		for ( int i = 0; i < cnt; i++ ) {
