@@ -63,6 +63,12 @@ public class Forward implements Serializable {
 	public Forward( int stat ) {
 		error = stat;
 		session_clear_f = true;
+		if ( stat == 403 ) {
+			System.out.println( "================ 403 Set  ==================" );
+			System.out.println( new java.util.Date().toString() );
+			Thread.dumpStack();
+			System.out.println( "============================================" );
+		}
 	}
 
 	/**
@@ -242,6 +248,10 @@ public class Forward implements Serializable {
 		if ( error != 0 ) {
 			if ( error == 403 ) {
 				Option.traceWithStack( "403 Forward" );
+				System.out.println( "================ 403 Forward  ==================" );
+				System.out.println( new java.util.Date().toString() );
+				Thread.dumpStack();
+				System.out.println( "================================================" );
 			}
 			ErrorStatus.send( res, error );
 			return;
