@@ -688,5 +688,27 @@ public class RequestParameter implements Serializable {
 		code ^= getRelativeURI().hashCode();
 		return Integer.toString( code, Character.MAX_RADIX );
 	}
+
+	/**
+	 * リクエスト情報の文字列化。
+	 */
+	public String toString() {
+		StringBuilder	buf = new StringBuilder();
+		String[]	header = getHeaderNames();
+		buf = buf.append( getMethod().toString() );
+		buf = buf.append( " " );
+		buf = buf.append( getURI() );
+		buf = buf.append( "\n" );
+		for ( int i = 0; i < header.length; i++ ) {
+			String[]	val = getHeader( header[i] );
+			for ( int  j = 0; j < val.length; j++ ) {
+				buf = new StringBuilder( header[i] );
+				buf = buf.append( " : " );
+				buf = buf.append( val[j] );
+				buf = buf.append( "\n" );
+			}
+		}
+		return buf.toString();
+	}
 }
 
