@@ -443,6 +443,7 @@ public class SandBox extends Thread {
 	static void doStart() {
 		synchronized( waiting ) {
 			if ( sand_box != null )	return;
+			ChildKiller.init( running );
 			sand_box = new SandBox();
 			sand_box.setDaemon( true );
 			sand_box.setPriority( MIN_PRIORITY );
@@ -576,7 +577,6 @@ public class SandBox extends Thread {
 	 * 既に同名処理があれば、このインスタンスは破棄されます。
 	 */
 	public static void startDaemon( String name, Daemon daemon ) {
-		ChildKiller.start( running );
 		History[]	hist = getCurrentHistory();
 		if ( hist == null )	return;
 		Child	child = null;
