@@ -105,7 +105,12 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	boolean isSame( HttpServletRequest req ) {
 		if ( client == getClient( req ) )	return true;
 		client = 0;
-		System.out.println( "unmatched client" );
+		System.out.println( "-- nmatched client --------------------------"  );
+		System.out.println( new Date().toString() );
+		System.out.println( "IP = " + req.getRemoteAddr() );
+		System.out.println( "User Agent = " + req.getHeader( RequestParameter.UA_HEAD ) );
+		System.out.println( "SessionID = " + req.getSession().getId() );
+		System.out.println( "---------------------------------------------\n" );
 		return false;
 	}
 
