@@ -533,6 +533,9 @@ this.url_check=function(url,param){
 	var jsession=url_test[0].split(";jsessionid");
 	url=jsession[0];
 
+	var na_test = url.split("\.");
+	if ( na_test[na_test.length-1]!="na")	return undefined;
+
 	if(url_test[1]){
 		url=url+"?"+url_test[1];
 		if(param)	url=url+"&"+param;
@@ -551,7 +554,7 @@ this.error_page=function(svr){
 this.get_a=function(o,url,key){
 	if(paraselene.get_a_calling)	return false;
 	url=paraselene.url_check(url,"paraselene_a_ajax="+key);
-	if(!url)	return false;
+	if(!url)	return true;
 	var org=o.onclick;
 	var svr=paraselene.get_http(function(svr){
 			if(svr.status!=200){
